@@ -1,11 +1,34 @@
 import os
 import numpy as np
 import pandas as pd
+
 from rpy2.robjects.packages import importr
 from rpy2.robjects import FloatVector, numpy2ri
+import rpy2.robjects as robjects
+import rpy2.robjects.packages as rpackages
 from datetime import datetime
+from rpy2.robjects.vectors import StrVector
 
 
+required_packages = ['ahead'] # list of required R packages 
+
+if all(rpackages.isinstalled(x) for x in required_packages):
+    check_packages = True # True if packages are already installed 
+else:
+   check_packages = False # False if packages are not installed 
+
+if check_packages == False: # Not installed? Then install.
+
+    packages_to_install = [x for x in required_packages if not rpackages.isinstalled(x)]
+    
+    if len(packages_to_install) > 0:
+        base = importr('base')
+        utils = importr('utils')
+        base.options(repos = base.c(techtonique = 'https://techtonique.r-universe.dev', 
+                                    CRAN = 'https://cloud.r-project.org'))
+        utils.install_packages(StrVector(packages_to_install))
+        check_packages = True 
+
 base = importr('base')
 stats = importr('stats')
 ahead = importr('ahead')
